@@ -348,7 +348,7 @@ void BNPView::initialize()
 	m_tree->setTreeStepSize(16);
 	m_tree->setLineWidth(1);
 	m_tree->setMidLineWidth(0);
-	m_tree->setFocusPolicy(TQ_NoFocus);
+	m_tree->setFocusPolicy(TQWidget::NoFocus);
 
 	/// Configure the List View Drag and Drop:
 	m_tree->setDragEnabled(true);
